@@ -149,9 +149,9 @@ class QtWidget(QtToolkitObject, ProxyWidget):
             if t:
                 parts.append(t)
         if len(parts) > 0:
-            stylesheet = u'\n\n'.join(parts)
+            stylesheet = '\n\n'.join(parts)
         else:
-            stylesheet = u''
+            stylesheet = ''
         self.widget.setStyleSheet(stylesheet)
 
     def tab_focus_request(self, reason):
